<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en_US">
<context>
    <name>AddMusicWidget</name>
    <message>
        <location filename="../src/music-player/mainFrame/addmusicwidget.cpp" line="70"/>
        <source>Add Music</source>
        <translation>Добавить музыку</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/addmusicwidget.cpp" line="80"/>
        <source>Or drag music files here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AlbumDataDelegate</name>
    <message>
        <location filename="../src/music-player/listView/albumList/albumdelegate.cpp" line="635"/>
        <source>No songs</source>
        <translation>Нет песен</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/albumList/albumdelegate.cpp" line="637"/>
        <source>1 song</source>
        <translation>1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/albumList/albumdelegate.cpp" line="639"/>
        <source>%1 songs</source>
        <translation>%1 песни</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <location filename="../src/music-player/listView/albumList/albumdelegate.cpp" line="251"/>
        <location filename="../src/music-player/listView/albumList/albumdelegate.cpp" line="416"/>
        <location filename="../src/music-player/listView/albumList/albumdelegate.cpp" line="620"/>
        <source>Unknown album</source>
        <translation>Неизвестный альбом</translation>
    </message>
</context>
<context>
    <name>CloseConfirmDialog</name>
    <message>
        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="57"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="52"/>
        <source>Minimize to system tray</source>
        <translation>Минимизировать в трей</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="62"/>
        <source>Do not ask again</source>
        <translation>Не спрашивать больше</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="70"/>
        <source>Please choose your action</source>
        <translation>Пожалуйста, выберите Ваше действие</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="83"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/closeconfirmdialog.cpp" line="84"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
<context>
    <name>DBOperate</name>
    <message>
        <location filename="../src/music-player/presenter/dboperate.cpp" line="139"/>
        <location filename="../src/music-player/presenter/dboperate.cpp" line="177"/>
        <location filename="../src/music-player/presenter/databaseservice.cpp" line="81"/>
        <location filename="../src/music-player/presenter/databaseservice.cpp" line="82"/>
        <source>Unknown album</source>
        <translation>Неизвестный альбом</translation>
    </message>
    <message>
        <location filename="../src/music-player/presenter/dboperate.cpp" line="142"/>
        <location filename="../src/music-player/presenter/dboperate.cpp" line="180"/>
        <location filename="../src/music-player/presenter/databaseservice.cpp" line="77"/>
        <location filename="../src/music-player/presenter/databaseservice.cpp" line="78"/>
        <source>Unknown artist</source>
        <translation>Неизвестный исполнитель</translation>
    </message>
</context>
<context>
    <name>DataBaseService</name>
    <message>
        <location filename="../src/music-player/presenter/databaseservice.cpp" line="1217"/>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
    <message>
        <location filename="../src/music-player/presenter/databaseservice.cpp" line="1226"/>
        <source>Artists</source>
        <translation>Исполнители</translation>
    </message>
    <message>
        <location filename="../src/music-player/presenter/databaseservice.cpp" line="1234"/>
        <source>All Music</source>
        <translation>Вся Музыка</translation>
    </message>
    <message>
        <location filename="../src/music-player/presenter/databaseservice.cpp" line="1241"/>
        <source>My Favorites</source>
        <translation>Избранное</translation>
    </message>
</context>
<context>
    <name>DequalizerDialog</name>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="274"/>
        <source>Custom</source>
        <translation>Пользовательский</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="275"/>
        <source>Monophony</source>
        <translation>Однотонность</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="276"/>
        <source>Classical</source>
        <translation>Классика</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="277"/>
        <source>Club</source>
        <translation>Клубный</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="278"/>
        <source>Dance</source>
        <translation>Танцевальный</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="279"/>
        <source>Full Bass</source>
        <translation>Низкие частоты</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="280"/>
        <source>Full Bass and Treble</source>
        <translation>Низкие и высокие частоты</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="281"/>
        <source>Full Treble</source>
        <translation>Высокие частоты</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="282"/>
        <source>Headphones</source>
        <translation>Наушники</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="283"/>
        <source>Hall</source>
        <translation>Зал</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="284"/>
        <source>Live</source>
        <translation>Лайв</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="285"/>
        <source>Party</source>
        <translation>Вечеринка</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="286"/>
        <source>Pop</source>
        <translation>Поп</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="287"/>
        <source>Reggae</source>
        <translation>Рэгги</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="288"/>
        <source>Rock</source>
        <translation>Рок</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="289"/>
        <source>Ska</source>
        <translation>Ска</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="290"/>
        <source>Soft</source>
        <translation>Мягко</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="291"/>
        <source>Soft Rock</source>
        <translation>Софт-рок</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="292"/>
        <source>Techno</source>
        <translation>Техно</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="71"/>
        <source>Equalizer</source>
        <translation>Эквалайзер</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="79"/>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="415"/>
        <source>ON</source>
        <translation>Вкл.</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="81"/>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="413"/>
        <source>OFF</source>
        <translation>Выкл.</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="102"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="131"/>
        <source>Preamplifier</source>
        <translation>Предусилитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="178"/>
        <source>Restore Defaults</source>
        <translation>Восстановить Значения по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="305"/>
        <location filename="../src/music-player/widget/dequalizerdialog.cpp" line="306"/>
        <source>Sound Effects Saved</source>
        <translation>Звуковые эффекты Сохранены</translation>
    </message>
</context>
<context>
    <name>FooterWidget</name>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="165"/>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="653"/>
        <source>Unknown Title</source>
        <translation>Неизвестное Название</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="172"/>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="656"/>
        <source>Unknown artist</source>
        <translation>Неизвестный исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="293"/>
        <source>Previous</source>
        <translation>Предыдущий</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="294"/>
        <source>Next</source>
        <translation>Далее</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="295"/>
        <source>Play/Pause</source>
        <translation>Воспроизведение / Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="296"/>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="297"/>
        <source>Lyrics</source>
        <translation>Текст песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="298"/>
        <source>Play Queue</source>
        <translation>Очередь воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="470"/>
        <source>List Loop</source>
        <translation>Непрерывно</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="473"/>
        <source>Single Loop</source>
        <translation>Одиночный Цикл</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/footerwidget.cpp" line="476"/>
        <source>Shuffle</source>
        <translation>Перемешать</translation>
    </message>
</context>
<context>
    <name>ImportWidget</name>
    <message>
        <location filename="../src/music-player/mainFrame/importwidget.cpp" line="79"/>
        <source>Open Folder</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/importwidget.cpp" line="88"/>
        <source>Add Music</source>
        <translation>Добавить музыку</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/importwidget.cpp" line="96"/>
        <location filename="../src/music-player/mainFrame/importwidget.cpp" line="233"/>
        <source>Scan</source>
        <translation>Сканируйте</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/importwidget.cpp" line="97"/>
        <location filename="../src/music-player/mainFrame/importwidget.cpp" line="234"/>
        <source>%1 music directory or drag music files here</source>
        <translation>%1 музыкальный каталог или перетащите музыкальный файл, чтобы добавить музыку</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/importwidget.cpp" line="210"/>
        <source>All music</source>
        <translation>Вся музыка</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/importwidget.cpp" line="406"/>
        <source>Loading music, please wait...</source>
        <translation>Загрузка музыки, пожалуйста ждите...</translation>
    </message>
</context>
<context>
    <name>InfoDialog</name>
    <message>
        <location filename="../src/music-player/widget/infodialog.cpp" line="122"/>
        <source>Basic info</source>
        <translation>Основная информация</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/infodialog.cpp" line="139"/>
        <source>Title:</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/infodialog.cpp" line="139"/>
        <source>Artist:</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/infodialog.cpp" line="140"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/infodialog.cpp" line="140"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/infodialog.cpp" line="141"/>
        <source>Size:</source>
        <translation>Размер:</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/infodialog.cpp" line="141"/>
        <source>Duration:</source>
        <translation>Продолжительность:</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/infodialog.cpp" line="142"/>
        <source>Path:</source>
        <translation>Путь:</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/infodialog.cpp" line="230"/>
        <source>Unknown artist</source>
        <translation>Неизвестный исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/infodialog.cpp" line="231"/>
        <source>Unknown album</source>
        <translation>Неизвестный альбом</translation>
    </message>
</context>
<context>
    <name>MainFrame</name>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="264"/>
        <source>Add playlist</source>
        <translation>Новый список воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="118"/>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="266"/>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="416"/>
        <source>Add music</source>
        <translation>Добавить музыку</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="267"/>
        <source>Equalizer</source>
        <translation>Эквалайзер</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="270"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="273"/>
        <source>Dark theme</source>
        <translation>Темная тема</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="277"/>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="332"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="89"/>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="98"/>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="106"/>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="344"/>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="90"/>
        <source>Music is a local music player with beautiful design and simple functions.</source>
        <translation>Плеер - это локальный музыкальный плеер с красивым дизайном и простыми функциями.</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="123"/>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="124"/>
        <source>Select All</source>
        <translation>Выбрать Все</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="125"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="326"/>
        <source>Play/Pause</source>
        <translation>Воспроизведение / Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="328"/>
        <source>Previous</source>
        <translation>Предыдущий</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="330"/>
        <source>Next</source>
        <translation>Следующий</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="514"/>
        <source>Successfully added to &quot;%1&quot;</source>
        <translation>Успешно добавлено &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="517"/>
        <source>Already added to the playlist</source>
        <translation>Уже добавлено в плейлист</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="520"/>
        <source>1 song added</source>
        <translation>Добавлен 1 трек</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="522"/>
        <source>%1 songs added</source>
        <translation>Добавлено %1 треков</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="526"/>
        <source>A disc is connected</source>
        <translation>Диск подключен</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="576"/>
        <source>Unsupported audio codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="697"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="690"/>
        <source>Import failed, no valid music file found</source>
        <translation>Не удалось импортировать, не найден действительный музыкальный файл</translation>
    </message>
</context>
<context>
    <name>MusicBaseListView</name>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicbaselistview.cpp" line="128"/>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicbaselistview.cpp" line="134"/>
        <source>Artists</source>
        <translation>Исполнители</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicbaselistview.cpp" line="140"/>
        <source>All Music</source>
        <translation>Вся Музыка</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicbaselistview.cpp" line="146"/>
        <source>My Favorites</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicbaselistview.cpp" line="181"/>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicbaselistview.cpp" line="354"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicbaselistview.cpp" line="184"/>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicbaselistview.cpp" line="350"/>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicbaselistview.cpp" line="187"/>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicbaselistview.cpp" line="352"/>
        <source>Add music</source>
        <translation>Добавить музыку</translation>
    </message>
</context>
<context>
    <name>MusicListDataWidget</name>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="115"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1030"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1051"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1070"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1085"/>
        <source>No songs</source>
        <translation>Нет песен</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="965"/>
        <source>Custom</source>
        <translation>Пользовательский</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1032"/>
        <source>1 album - 1 song</source>
        <translation>1 альбом - 1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1035"/>
        <source>%1 album - %2 songs</source>
        <translation>   %1 альбом - %2 песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1037"/>
        <source>%1 albums - %2 songs</source>
        <translation>   %1 альбом - %2 песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1053"/>
        <source>1 artist - 1 song</source>
        <translation>1 артист - 1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1056"/>
        <source>%1 artist - %2 songs</source>
        <translation>   %1 артист - %2 песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1058"/>
        <source>%1 artists - %2 songs</source>
        <translation>   %1 артисты - %2 песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="117"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1072"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1087"/>
        <source>1 song</source>
        <translation>1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="119"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1074"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="1089"/>
        <source>%1 songs</source>
        <translation>%1 песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="287"/>
        <source>Search Results</source>
        <translation>Результаты поиска</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="989"/>
        <source>No search results</source>
        <translation>Ничего не найдено</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="851"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="874"/>
        <source>All Music</source>
        <translation>Вся Музыка</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="239"/>
        <source>CD playlist</source>
        <translation>Плейлист компакт-диска</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="919"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="934"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="949"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="966"/>
        <source>Time added</source>
        <translation>Время добавления</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="920"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="952"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="969"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="935"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="951"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="968"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="950"/>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="967"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistdatawidget.cpp" line="830"/>
        <source>Play All</source>
        <translation>Воспроизвести Всё</translation>
    </message>
</context>
<context>
    <name>MusicListScrollArea</name>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistscrollarea.cpp" line="73"/>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/musiclistscrollarea.cpp" line="89"/>
        <source>Playlists</source>
        <translation>Списки воспроизведения</translation>
    </message>
</context>
<context>
    <name>MusicLyricWidget</name>
    <message>
        <location filename="../src/music-player/widget/lrc/musiclyricwidget.cpp" line="81"/>
        <source>No lyrics yet</source>
        <translation>Пока нет текста песни</translation>
    </message>
</context>
<context>
    <name>MusicSongListView</name>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="207"/>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="455"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="210"/>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="451"/>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="216"/>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="453"/>
        <source>Add music</source>
        <translation>Добавить музыку</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="217"/>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="457"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="218"/>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="339"/>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="459"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="301"/>
        <source>CD playlist</source>
        <translation>Плейлист компакт-диска</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="331"/>
        <source>Are you sure you want to delete this playlist?</source>
        <translation>Вы действительно хотите удалить этот список воспроизведения?</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="338"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="576"/>
        <source>The CD has been removed</source>
        <translation>Компакт диск был извлечен</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="580"/>
        <source>Play failed, as the CD has been removed</source>
        <translation>Воспроизведение не удалось, так как компакт-диск был удален</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="587"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicBaseAndSongList/musicsonglistview.cpp" line="964"/>
        <source>New playlist</source>
        <translation>Новый список воспроизведения</translation>
    </message>
</context>
<context>
    <name>PlayListView</name>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="488"/>
        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="839"/>
        <source>Unknown artist</source>
        <translation>Неизвестный исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="500"/>
        <location filename="../src/music-player/listView/musicInfoList/playitemdelegate.cpp" line="851"/>
        <source>Unknown album</source>
        <translation>Неизвестный альбом</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1291"/>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1864"/>
        <source>Play queue</source>
        <translation>Очередь воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1294"/>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1861"/>
        <source>My favorites</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="581"/>
        <source>File is invalid or does not exist, load failed</source>
        <translation>Файл недействителен или не существует, не удалось загрузить</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="582"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1332"/>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1335"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1860"/>
        <source>Add to playlist</source>
        <translation>Добавить список воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1344"/>
        <source>Display in file manager</source>
        <translation>Отобразить в менеджере файлов</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1270"/>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1342"/>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1408"/>
        <source>Add to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1298"/>
        <source>Create new playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1346"/>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1410"/>
        <source>Remove from play queue</source>
        <translation>Удалить из игровой очереди</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1348"/>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1412"/>
        <source>Remove from playlist</source>
        <translation>Удалить из списка воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1351"/>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1414"/>
        <source>Delete from local disk</source>
        <translation>Удалить с локального диска</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1384"/>
        <source>Encoding</source>
        <translation>Кодировка</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1388"/>
        <source>Song info</source>
        <translation>Информация о песне</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1106"/>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1159"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1107"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1110"/>
        <source>Are you sure you want to remove %1?</source>
        <translation>Вы уверены, что хотите удалить %1?</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1112"/>
        <source>Are you sure you want to remove the selected %1 songs?</source>
        <translation>Вы уверены, что хотите удалить выделенные %1 треков?</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1160"/>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1268"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1165"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Вы уверены, что хотите удалить %1?</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1172"/>
        <source>Are you sure you want to delete the selected %1 songs?</source>
        <translation>Вы уверены, что хотите удалить выбранные %1 песни?</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/musicInfoList/playlistview.cpp" line="1173"/>
        <source>The song files contained will also be deleted</source>
        <translation>Файлы, содержащую песню будут также удалены</translation>
    </message>
</context>
<context>
    <name>PlayQueueWidget</name>
    <message>
        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="71"/>
        <source>Play Queue</source>
        <translation>Очередь воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="84"/>
        <source>Empty</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="95"/>
        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="337"/>
        <source>No songs</source>
        <translation>Нет песен</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="339"/>
        <source>1 song</source>
        <translation>1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/playqueuewidget.cpp" line="341"/>
        <source>%1 songs</source>
        <translation>%1 песни</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="92"/>
        <location filename="../src/music-player/mainFrame/mainframe.cpp" line="96"/>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="26"/>
        <source>Minimize to system tray</source>
        <translation>Минимизировать в трей </translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="27"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="28"/>
        <source>Ask me always</source>
        <translation>Спрашивать меня всегда</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="29"/>
        <source>Autoplay</source>
        <translation>Автовоспроизведение</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="30"/>
        <source>Enable fade in/out</source>
        <translation>Включить замирание вход/выход</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="31"/>
        <source>Remember playback position</source>
        <translation>Запомнить воспроизводимую позицию</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="32"/>
        <source>Close Main Window</source>
        <translation>Закрыть Главное Окно</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="33"/>
        <source>Basic</source>
        <translation>Основной</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="34"/>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="35"/>
        <source>Shortcuts</source>
        <translation>Горячие Клавиши</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="36"/>
        <source>Restore Defaults</source>
        <translation>Восстановить Значения по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="37"/>
        <source>Next</source>
        <translation>Далее</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="38"/>
        <source>Play/Pause</source>
        <translation>Воспроизведение / Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="39"/>
        <source>Previous</source>
        <translation>Предыдущий</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="40"/>
        <source>Volume down</source>
        <translation>Тише</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="41"/>
        <source>Volume up</source>
        <translation>Громче</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/settingsdialog.cpp" line="43"/>
        <source>Equalizer</source>
        <translation>Эквалайзер</translation>
    </message>
</context>
<context>
    <name>SearchResult</name>
    <message>
        <location filename="../src/music-player/mainFrame/searchresult.cpp" line="53"/>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/searchresult.cpp" line="74"/>
        <source>Artists</source>
        <translation>Исполнители</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/searchresult.cpp" line="95"/>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
</context>
<context>
    <name>SearchResultTabWidget</name>
    <message>
        <location filename="../src/music-player/widget/searchresulttabwidget.cpp" line="65"/>
        <source>Songs</source>
        <translation>Треки</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/searchresulttabwidget.cpp" line="72"/>
        <source>Artists</source>
        <translation>Исполнители</translation>
    </message>
    <message>
        <location filename="../src/music-player/widget/searchresulttabwidget.cpp" line="80"/>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="32"/>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="33"/>
        <source>Songs</source>
        <translation>Песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="34"/>
        <source>Playlists</source>
        <translation>Списки воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="35"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="42"/>
        <source>Play/Pause</source>
        <translation>Воспроизведение / Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="43"/>
        <source>Previous</source>
        <translation>Предыдущий</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="44"/>
        <source>Next</source>
        <translation>Далее</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="45"/>
        <source>Volume Up</source>
        <translation>Громче</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="46"/>
        <source>Volume Down</source>
        <translation>Тише</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="47"/>
        <source>Mute</source>
        <translation>Приглушить</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="50"/>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="51"/>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="52"/>
        <source>Song info</source>
        <translation>Информация о песне</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="55"/>
        <source>New playlist</source>
        <translation>Новый список воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="56"/>
        <source>Add music</source>
        <translation>Добавить музыку</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="57"/>
        <source>Rename playlist</source>
        <translation>Переименовать список воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="58"/>
        <source>Remove from playlist</source>
        <translation>Удалить из списка воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="61"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../src/music-player/core/util/shortcut.cpp" line="62"/>
        <source>Display shortcuts</source>
        <translation>Горячие клавиши</translation>
    </message>
</context>
<context>
    <name>SingerDataDelegate</name>
    <message>
        <location filename="../src/music-player/listView/singerList/singerdelegate.cpp" line="619"/>
        <source>No songs</source>
        <translation>Нет песен</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/singerList/singerdelegate.cpp" line="621"/>
        <source>1 song</source>
        <translation>1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/listView/singerList/singerdelegate.cpp" line="623"/>
        <source>%1 songs</source>
        <translation>%1 песни</translation>
    </message>
</context>
<context>
    <name>SingerListView</name>
    <message>
        <location filename="../src/music-player/listView/singerList/singerdelegate.cpp" line="241"/>
        <location filename="../src/music-player/listView/singerList/singerdelegate.cpp" line="384"/>
        <location filename="../src/music-player/listView/singerList/singerdelegate.cpp" line="609"/>
        <location filename="../src/music-player/listView/albumList/albumdelegate.cpp" line="259"/>
        <location filename="../src/music-player/listView/albumList/albumdelegate.cpp" line="423"/>
        <location filename="../src/music-player/listView/albumList/albumdelegate.cpp" line="628"/>
        <source>Unknown artist</source>
        <translation>Неизвестный исполнитель</translation>
    </message>
</context>
<context>
    <name>SubSonglistWidget</name>
    <message>
        <location filename="../src/music-player/mainFrame/subsonglistwidget.cpp" line="87"/>
        <source>Play All</source>
        <translation>Воспроизвести Всё</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainFrame/subsonglistwidget.cpp" line="108"/>
        <source>Shuffle</source>
        <translation>Перемешать</translation>
    </message>
</context>
<context>
    <name>TitlebarWidget</name>
    <message>
        <location filename="../src/music-player/widget/titlebarwidget.cpp" line="59"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
</TS>
